@@ -23,20 +23,21 @@ def text_element(
         value (str): The value to be passed down the app
     """
     if (
-            text_type.value != TextType.PLAIN_TEXT
-            and text_type.value != TextType.MARKDOWN_TEXT
+            text_type.value != TextType.PLAIN_TEXT.value
+            and text_type.value != TextType.MARKDOWN_TEXT.value
     ):
         raise ValueError("text_type must be `plain_text` or `mrkdwn`")
     node = {
         "text": {
-            "type": text_type,
+            "type": text_type.value,
             "text": text,
-            "emoji": emoji,
-            "verbatim": verbatim
+            "emoji": emoji
         }
     }
     if value is not None:
         node["value"] = value
-    if text_type == TextType.MARKDOWN_TEXT:
+    if text_type == TextType.MARKDOWN_TEXT.value:
         node.pop("emoji")
+    if verbatim:
+        node['text']['verbatim'] = True
     return node
