@@ -1,4 +1,4 @@
-from section_elements import (
+from .section_elements import (
     plain_text,
     markdown_text,
     text_fields,
